@@ -37,7 +37,7 @@ Group by StressVowel,buckeyebrowser_speaker.Number""")
 
 def get_outliers(filename):
     dist = get_dist()
-    outs = loadFile(filename,cols=['Token','Word','Speaker','Vowel','F1','F2'])
+    outs = loadFile(os.path.join(fetch_media_resource('Results'),'Buckeye',filename),cols=['Token','Word','Speaker','Vowel','F1','F2'])
     outliers = []
     for o in outs:
         #o['Token'] = int(o['Token'])
